@@ -6,11 +6,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#if defined(DARWIN)
-#include <sys/malloc.h>
-#else
-#include <malloc.h>
-#endif
 #include <sys/types.h>
 
 #ifdef HAVE_DIRENT_H
@@ -114,6 +109,8 @@ void dragfilebox(xcWidget w, caddr_t clientdata, XMotionEvent *event)
 	   10 + FILECHARHEIGHT * (flcurrent
 	   - flstart), flcurwidth + 10, FILECHARHEIGHT);
 
+   if (files == NULL) return;
+
    twidth = XTextWidth(appdata.filefont, files[filenum].filename,
 	    strlen(files[filenum].filename));
    XDrawRectangle(dpy, lwin, areastruct.gc, 5,
@@ -219,7 +216,7 @@ void crashrecover()
       unlink(xobjs.tempfile);
       free(xobjs.tempfile);
    }
-   xobjs.tempfile = strdup(_STR2);
+   xobjs.tempfile = mystrdup(_STR2);
 
    startloadfile();
 }
@@ -448,14 +445,14 @@ void newfilelist(xcWidget w, popupstruct *okaystruct)
 #ifdef TCL_WRAPPER
    int bval;
    int result;
-   char *cstr = Tcl_GetVar(xcinterp, "filter", TCL_NAMESPACE_ONLY);
+   char *cstr = Tcl_GetVar2(xcinterp, "XCOps", "filter", TCL_NAMESPACE_ONLY);
    if (cstr == NULL) {
-      Wprintf("Error: No variable $filter in Tcl!");
+      Wprintf("Error: No variable $XCOps(filter) in Tcl!");
       return;
    }
    result = Tcl_GetBoolean(xcinterp, cstr, &bval);
    if (result != TCL_OK) {
-      Wprintf("Error: Bad variable $filter in Tcl!");
+      Wprintf("Error: Bad variable $XCOps(filter) in Tcl!");
       return;  
    }
    areastruct.filefilter = bval;
@@ -506,6 +503,8 @@ void fileselect(xcWidget w, popupstruct *okaystruct, XButtonEvent *event)
    XtGetValues(w, wargs, n);
 #endif
 
+   if (files == NULL) return;	/* shouldn't happen */
+
    /* third mouse button cancels selection and reverts buffer to cwd name */
 
    if (event->button == Button3) {
