@@ -651,6 +651,9 @@ void composelib(short mode)
    short fval;
    short llx, lly, width, height;
 
+   int totalarea, targetwidth;
+   double scale;
+
    /* Also make composelib() a wrapper for composepagelib() */
    if ((mode > FONTLIB) && (mode < LIBRARY)) {
       composepagelib(mode);
@@ -674,6 +677,35 @@ void composelib(short mode)
 
    fval = findhelvetica();
 
+   /* experimental:  attempt to produce a library with the same aspect  */
+   /* ratio as the drawing window.                                      */
+
+   totalarea = 0;
+   for (spec = xobjs.userlibs[mode - LIBRARY].instlist; spec != NULL;
+                spec = spec->next) {
+      libobj = spec->thisinst->thisobject;
+
+      /* "Hidden" objects are not drawn */
+      if (libobj->hidden == True) continue;
+
+      drawinst = spec->thisinst;
+      drawinst->position.x = 0;
+      drawinst->position.y = 0;
+
+      /* Get the bounding box of the instance in the page's coordinate system */
+      calcinstbbox((genericptr *)(&drawinst), &llx, &lly, &width, &height);
+      width -= llx;	/* convert urx to width */
+      height -= lly;	/* convert ury to height */
+      width += 30;	/* space padding */
+      height += 30;	/* height padding */
+      if (width < 200) width = 200;	/* minimum box width */
+      if (height < 220) height = 220;	/* minimum box height */
+      totalarea += (width * height);
+   }
+
+   scale = (double)totalarea / (double)(areastruct.width * areastruct.height);
+   targetwidth = (int)(sqrt(scale) * (double)areastruct.width);
+
    /* generate the list of object instances and their labels */
 
    for (spec = xobjs.userlibs[mode - LIBRARY].instlist; spec != NULL;
@@ -695,7 +727,8 @@ void composelib(short mode)
       /* Determine the area needed on the page to draw the object */
 
       nxpos = xpos + ((width > 170) ? width + 30 : 200);
-      if ((nxpos > (areastruct.width << 1)) && (xpos > 0)) {
+      /* if ((nxpos > (areastruct.width << 1)) && (xpos > 0)) { */
+      if ((nxpos > targetwidth) && (xpos > 0)) {
 	 nxpos -= xpos; 
 	 xpos = 0;
 	 ypos -= nypos;
@@ -727,7 +760,7 @@ void composelib(short mode)
 	 (*drawname)->string->data.font = fval;
 	 strptr = makesegment(&((*drawname)->string), NULL);
 	 strptr->type = TEXT_STRING;
-         strptr->data.string = strdup(libobj->name);
+         strptr->data.string = mystrdup(libobj->name);
          (*drawname)->justify = TOP | NOTBOTTOM | NOTLEFT;
 
          if (width > 170)
@@ -1188,7 +1221,7 @@ void copycat()
       for (ops = oldobj->params; ops != NULL; ops = ops->next) {
 	 newops = (oparamptr)malloc(sizeof(oparam));
 	 newops->next = (*newobj)->params;
-	 newops->key = strdup(ops->key);
+	 newops->key = mystrdup(ops->key);
 	 (*newobj)->params = newops;
 	 newops->type = ops->type;
 	 newops->which = ops->which;
@@ -1203,7 +1236,7 @@ void copycat()
 	       newops->parameter.string = stringcopy(ops->parameter.string);
 	       break;
 	    case XC_EXPR:
-	       newops->parameter.expr = strdup(ops->parameter.expr);
+	       newops->parameter.expr = mystrdup(ops->parameter.expr);
 	       break;
 	 }
       }
