@@ -373,7 +373,7 @@ void settsize(xcWidget w, labelptr settext)
 	    redrawtext(nstext);
 	 }
       }
-      objectdeselect();
+      unselect_all();
    }
 }
 
@@ -441,13 +441,8 @@ void autoscale(int page)
    }
    else {
 
-#ifdef SCHEMA
       width = toplevelwidth(areastruct.topinstance, NULL);
       height = toplevelheight(areastruct.topinstance, NULL);
-#else
-      width = topobject->bbox.width;
-      height = topobject->bbox.height;
-#endif
    }
 
    if (xobjs.pagelist[page]->orient == 0) {	/* Portrait */
@@ -837,12 +832,12 @@ void setosize(xcWidget w, objinstptr dataptr)
    }
    for (osel = areastruct.selectlist; osel < areastruct.selectlist +
 	     areastruct.selects; osel++) {
-      if (SELECTTYPE(osel) == OBJECT) {
+      if (SELECTTYPE(osel) == OBJINST) {
 	 nsobj = SELTOOBJINST(osel);
          nsobj->scale = tmpres;
       }
    }
-   objectdeselect();
+   unselect_all();
    pwriteback(areastruct.topinstance);
    drawarea(NULL, NULL, NULL);
 }
@@ -861,7 +856,7 @@ void getosize(xcWidget button, caddr_t clientdata, caddr_t calldata)
    objinstptr setobj = NULL;
 
    for (; osel < areastruct.selectlist + areastruct.selects; osel++)
-      if (SELECTTYPE(osel) == OBJECT) {
+      if (SELECTTYPE(osel) == OBJINST) {
 	 setobj = SELTOOBJINST(osel);
 	 selects++;
 	 break;
@@ -934,7 +929,7 @@ void setwwidth(xcWidget w, void *dataptr)
             nspath->width = tmpres;
          }
       }
-      objectdeselect();
+      unselect_all();
       pwriteback(areastruct.topinstance);
       drawarea(NULL, NULL, NULL);
    }
@@ -954,19 +949,19 @@ void getwwidth(xcWidget button, caddr_t clientdata, caddr_t calldata)
 
    for (; osel < areastruct.selectlist + areastruct.selects; osel++) {
       setel = *(topobject->plist + (*osel));
-      if (setel->type == ARC) {
+      if (IS_ARC(setel)) {
 	 flval = ((arcptr)setel)->width;
 	 break;
       }
-      else if (setel->type == POLYGON) {
+      else if (IS_POLYGON(setel)) {
 	 flval = ((polyptr)setel)->width;
 	 break;
       }
-      else if (setel->type == SPLINE) {
+      else if (IS_SPLINE(setel)) {
 	 flval = ((splineptr)setel)->width;
 	 break;
       }
-      else if (setel->type == PATH) {
+      else if (IS_PATH(setel)) {
 	 flval = ((pathptr)setel)->width;
 	 break;
       }
@@ -1011,14 +1006,14 @@ void setfilename(xcWidget w, char **dataptr)
    if (!strcmp(*dataptr, _STR2)) return;   /* no change in string */
 
    /* Make the change to the current page */
-   xobjs.pagelist[areastruct.page]->filename = strdup(_STR2);
+   xobjs.pagelist[areastruct.page]->filename = mystrdup(_STR2);
 
    /* All existing filenames which match the old string should also be changed */
    for (cpage = 0; cpage < xobjs.pages; cpage++) {
       if ((xobjs.pagelist[cpage]->pageinst != NULL) && (cpage != areastruct.page)) {
 	 if (!strcmp(xobjs.pagelist[cpage]->filename, oldstr)) {
 	    free(xobjs.pagelist[cpage]->filename);
-	    xobjs.pagelist[cpage]->filename = strdup(_STR2);
+	    xobjs.pagelist[cpage]->filename = mystrdup(_STR2);
 	 }
       }
    }
@@ -1048,11 +1043,9 @@ void setpagelabel(xcWidget w, char *dataptr)
    else
       sprintf(topobject->name, "%.79s", _STR2);
 
-#ifdef SCHEMA
    /* For schematics, all pages with associations to symbols must have	*/
    /* unique names.							*/
    if (topobject->symschem != NULL) checkpagename(topobject);
-#endif
 
    printname(topobject);
    renamepage(areastruct.page);
@@ -1130,7 +1123,8 @@ void makenewencodingbutton(char *ename, char value)
 
 void togglefontmark(int fontval)
 {
-   Tcl_SetVar(xcinterp, "fontfamily", fonts[fontval].family, TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2(xcinterp, "XCOps", "fontfamily", fonts[fontval].family,
+		TCL_NAMESPACE_ONLY);
 }
 
 #else
@@ -1306,7 +1300,7 @@ void togglegrid(u_short type)
    /* string; doing so prevents the menu from recognizing the variable	*/
    /* value.								*/
 
-   Tcl_SetVar(xcinterp, "gridstyle", stylenames[type], TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2(xcinterp, "XCOps", "gridstyle", stylenames[type], TCL_NAMESPACE_ONLY);
 }
 
 #else
@@ -1587,7 +1581,6 @@ void renamepage(short pagenumber)
       Fprintf(stderr, "Error:  No Button Widget named \"%9s\"\n", bname);
 #endif
 
-#ifdef SCHEMA
    /* If the page had a master but now has a different	*/
    /* name, disconnect the schematics.			*/
 
@@ -1614,7 +1607,6 @@ void renamepage(short pagenumber)
 	 break;
       }
    }
-#endif
 
 }
 
@@ -1708,7 +1700,7 @@ void setcolormark(int colorval)
 	    break;
       objv[2] = Tcl_NewIntObj((int)i);
    }
-   Tcl_SetVar2Ex(xcinterp, "colorval", NULL, objv[2], TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2Ex(xcinterp, "XCOps", "colorval", objv[2], TCL_NAMESPACE_ONLY);
 
    XcTagCallback(xcinterp, 3, objv);
 #endif
@@ -1768,7 +1760,7 @@ void setallstylemarks(u_short styleval)
    /* Set GUI variables and execute any command tags associated	*/
    /* with the "fill" and "border" commands.			*/
 
-   Tcl_Obj *objv[2];
+   Tcl_Obj *objv[3];
    int fillfactor;
    const char *bptr;
 
@@ -1787,13 +1779,18 @@ void setallstylemarks(u_short styleval)
    else
       objv[1] = Tcl_NewStringObj("unfilled", 8);
 
-   Tcl_SetVar2Ex(xcinterp, "fillamount", NULL, objv[1], TCL_NAMESPACE_ONLY);
-   Tcl_SetVar(xcinterp, "opaque", (styleval & OPAQUE) ? "true" : "false",
+   if (styleval & OPAQUE)
+      objv[2] = Tcl_NewStringObj("opaque", 6);
+   else
+      objv[2] = Tcl_NewStringObj("transparent", 11);
+
+   Tcl_SetVar2Ex(xcinterp, "XCOps", "fillamount", objv[1], TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2(xcinterp, "XCOps", "opaque", (styleval & OPAQUE) ? "true" : "false",
 		TCL_NAMESPACE_ONLY);
-   Tcl_SetVar(xcinterp, "bboxtype", (styleval & BBOX) ? "true" : "false",
-		TCL_NAMESPACE_ONLY);
-   Tcl_SetVar(xcinterp, "polyclosed", (styleval & UNCLOSED) ? "false" : "true",
+   Tcl_SetVar2(xcinterp, "XCOps", "bboxtype", (styleval & BBOX) ? "true" : "false",
 		TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2(xcinterp, "XCOps", "polyclosed", (styleval & UNCLOSED) ? "false" :
+		"true", TCL_NAMESPACE_ONLY);
 
    switch (styleval & BORDERS) {
       case DASHED:
@@ -1809,9 +1806,9 @@ void setallstylemarks(u_short styleval)
 	 bptr = borders[SolidIdx];
 	 break;
    }
-   Tcl_SetVar(xcinterp, "linestyle", (char *)bptr, TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2(xcinterp, "XCOps", "linestyle", (char *)bptr, TCL_NAMESPACE_ONLY);
 
-   XcTagCallback(xcinterp, 2, objv);
+   XcTagCallback(xcinterp, 3, objv);
 
 #endif
 }
@@ -1826,7 +1823,7 @@ polyptr checkforbbox(objectptr localdata)
 
    for (cbbox = (polyptr *)localdata->plist; cbbox <
 	(polyptr *)localdata->plist + localdata->parts; cbbox++)
-      if ((*cbbox)->type == POLYGON)
+      if (IS_POLYGON(*cbbox))
          if ((*cbbox)->style & BBOX) return *cbbox;
 
    return NULL;
@@ -1838,7 +1835,7 @@ polyptr checkforbbox(objectptr localdata)
 /* off.								*/
 /*--------------------------------------------------------------*/
 
-void setelementstyle(xcWidget w, u_short value, u_short mask)
+int setelementstyle(xcWidget w, u_short value, u_short mask)
 {
    Boolean selected = False;
    short *sstyle;
@@ -1849,23 +1846,23 @@ void setelementstyle(xcWidget w, u_short value, u_short mask)
 	 polyptr ckp;
 	 if (areastruct.selects != 1) {
 	    Wprintf("Choose only one polygon to be the bounding box");
-	    return;
+	    return -1;
 	 }
 	 else if (SELECTTYPE(areastruct.selectlist) != POLYGON) {
 	    Wprintf("Bounding box can only be a polygon");
-	    return;
+	    return -1;
 	 }
 	 else if (((ckp = checkforbbox(topobject)) != NULL) &&
 		(ckp != SELTOPOLY(areastruct.selectlist))) {
 	    Wprintf("Only one bounding box allowed per page");
-	    return;
+	    return -1;
 	 }
       }
 
       for (sstyle = areastruct.selectlist; sstyle < areastruct.selectlist
 	   + areastruct.selects; sstyle++) {
 	 short stype = SELECTTYPE(sstyle);
-	 if (stype == ARC || stype == POLYGON || stype == SPLINE || stype == PATH) {
+	 if (stype & (ARC | POLYGON | SPLINE | PATH)) {
 	    short *estyle;
 	    switch (stype) {
 	       case ARC:
@@ -1912,7 +1909,7 @@ void setelementstyle(xcWidget w, u_short value, u_short mask)
       if (value & BBOX) {
 	 Wprintf("Cannot set default style to Bounding Box");
 	 newstyle &= ~(BBOX);
-	 return;
+	 return -1;
       }
       else {
 	 newstyle &= ~mask;
@@ -1921,17 +1918,21 @@ void setelementstyle(xcWidget w, u_short value, u_short mask)
 
       if ((newstyle & NOBORDER) && !(newstyle & FILLED)) {
 	 Wprintf("Must have either a border or filler");
-	 return;
+	 return -1;
       }
       areastruct.style = newstyle;
       overdrawpixmap(w);
    }
+#ifndef TCL_WRAPPER
    setallstylemarks(newstyle);
-   objectdeselect();
+   unselect_all();
+#endif
+   return (int)newstyle;
 }
 
+#ifndef TCL_WRAPPER
 /*--------------------------------------------------------------*/
-/* The following four routines are all wrappers for		*/
+/* The following five routines are all wrappers for		*/
 /* setelementstyle(),	  					*/
 /* used in menudefs to differentiate between sections, each of  */
 /* which has settings independent of the others.		*/
@@ -1958,23 +1959,26 @@ void setclosure(xcWidget w, pointertype value, caddr_t calldata)
 
 /*----------------------------------------------------------------*/
 
-void setline(xcWidget w, pointertype value, caddr_t calldata)
-{
-   setelementstyle(w, (u_short)value, BORDERS);
-}
-
-/*----------------------------------------------------------------*/
-
 void setopaque(xcWidget w, pointertype value, caddr_t calldata)
 {
    setelementstyle(w, (u_short)value, OPAQUE);
 }
    
+#endif /* TCL_WRAPPER */
+
+/*----------------------------------------------------------------*/
+
+int setline(xcWidget w, pointertype value, caddr_t calldata)
+{
+   return setelementstyle(w, (u_short)value, BORDERS);
+}
+
 /*-----------------------------------------------*/
 /* Set the color value for all selected elements */
 /*-----------------------------------------------*/
 
 #ifdef TCL_WRAPPER
+
 void setcolor(xcWidget w, int cindex)
 {
    short *scolor;
@@ -2051,7 +2055,9 @@ void setcolor(xcWidget w, pointertype value, caddr_t calldata)
       overdrawpixmap(w);
    }
 
-   objectdeselect();
+#ifndef TCL_WRAPPER
+   unselect_all();
+#endif
 }
 
 /*----------------------------------------------------------------*/
@@ -2111,13 +2117,14 @@ void addnewcolor(xcWidget w, caddr_t clientdata, caddr_t calldata)
 void togglestylemark(int styleval)
 {
    switch(styleval) {
-      case 0: Tcl_SetVar(xcinterp, "fontstyle", "normal", TCL_NAMESPACE_ONLY);
+      case 0: Tcl_SetVar2(xcinterp, "XCOps", "fontstyle", "normal", TCL_NAMESPACE_ONLY);
 	 break;
-      case 1: Tcl_SetVar(xcinterp, "fontstyle", "bold", TCL_NAMESPACE_ONLY);
+      case 1: Tcl_SetVar2(xcinterp, "XCOps", "fontstyle", "bold", TCL_NAMESPACE_ONLY);
 	 break;
-      case 2: Tcl_SetVar(xcinterp, "fontstyle", "italic", TCL_NAMESPACE_ONLY);
+      case 2: Tcl_SetVar2(xcinterp, "XCOps", "fontstyle", "italic", TCL_NAMESPACE_ONLY);
 	 break;
-      case 3: Tcl_SetVar(xcinterp, "fontstyle", "bolditalic", TCL_NAMESPACE_ONLY);
+      case 3: Tcl_SetVar2(xcinterp, "XCOps", "fontstyle", "bolditalic",
+		TCL_NAMESPACE_ONLY);
 	 break;
    }
 }
@@ -2127,21 +2134,29 @@ void togglestylemark(int styleval)
 void toggleencodingmark(int encodingval)
 {
    switch(encodingval) {
-      case 0: Tcl_SetVar(xcinterp, "fontencoding", "Standard", TCL_NAMESPACE_ONLY);
+      case 0: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "Standard",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case 1: Tcl_SetVar(xcinterp, "fontencoding", "special", TCL_NAMESPACE_ONLY);
+      case 1: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "special",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case 2: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin1", TCL_NAMESPACE_ONLY);
+      case 2: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin1",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case 3: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin2", TCL_NAMESPACE_ONLY);
+      case 3: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin2",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case 4: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin3", TCL_NAMESPACE_ONLY);
+      case 4: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin3",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case 5: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin4", TCL_NAMESPACE_ONLY);
+      case 5: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin4",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case 6: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin5", TCL_NAMESPACE_ONLY);
+      case 6: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin5",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case 7: Tcl_SetVar(xcinterp, "fontencoding", "ISOLatin6", TCL_NAMESPACE_ONLY);
+      case 7: Tcl_SetVar2(xcinterp, "XCOps", "fontencoding", "ISOLatin6",
+		TCL_NAMESPACE_ONLY);
 	 break;
    }
 }
@@ -2151,35 +2166,39 @@ void toggleencodingmark(int encodingval)
 void togglejustmarks(int justvalue)
 {
    switch(justvalue & RLJUSTFIELD) {
-      case NORMAL: Tcl_SetVar(xcinterp, "jhoriz", "left", TCL_NAMESPACE_ONLY);
+      case NORMAL: Tcl_SetVar2(xcinterp, "XCOps", "jhoriz", "left",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case NOTLEFT: Tcl_SetVar(xcinterp, "jhoriz", "center", TCL_NAMESPACE_ONLY);
+      case NOTLEFT: Tcl_SetVar2(xcinterp, "XCOps", "jhoriz", "center",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case RIGHT|NOTLEFT: Tcl_SetVar(xcinterp, "jhoriz", "right", TCL_NAMESPACE_ONLY);
+      case RIGHT|NOTLEFT: Tcl_SetVar2(xcinterp, "XCOps", "jhoriz", "right",
+		TCL_NAMESPACE_ONLY);
 	 break;
    }
    switch(justvalue & TBJUSTFIELD) {
-      case NORMAL: Tcl_SetVar(xcinterp, "jvert", "bottom", TCL_NAMESPACE_ONLY);
+      case NORMAL: Tcl_SetVar2(xcinterp, "XCOps", "jvert", "bottom",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case NOTBOTTOM: Tcl_SetVar(xcinterp, "jvert", "middle", TCL_NAMESPACE_ONLY);
+      case NOTBOTTOM: Tcl_SetVar2(xcinterp, "XCOps", "jvert", "middle",
+		TCL_NAMESPACE_ONLY);
 	 break;
-      case TOP|NOTBOTTOM: Tcl_SetVar(xcinterp, "jvert", "top", TCL_NAMESPACE_ONLY);
+      case TOP|NOTBOTTOM: Tcl_SetVar2(xcinterp, "XCOps", "jvert", "top",
+		TCL_NAMESPACE_ONLY);
 	 break;
    }
 
    /* Flip Invariance property */
-   Tcl_SetVar(xcinterp, "flipinvariant", (justvalue & FLIPINV) ? "true" : "false",
-	TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2(xcinterp, "XCOps", "flipinvariant", (justvalue & FLIPINV) ?
+		"true" : "false", TCL_NAMESPACE_ONLY);
 
    /* LaTeX mode property */
-   Tcl_SetVar(xcinterp, "latexmode", (justvalue & LATEXLABEL) ? "true" : "false",
-	TCL_NAMESPACE_ONLY);
+   Tcl_SetVar2(xcinterp, "XCOps", "latexmode", (justvalue & LATEXLABEL) ?
+		"true" : "false", TCL_NAMESPACE_ONLY);
      
-#ifdef SCHEMA
    /* Pin visibility property */
-   Tcl_SetVar(xcinterp, "pinvisible", (justvalue & PINVISIBLE) ? "true" : "false",
-	TCL_NAMESPACE_ONLY);
-#endif
+   Tcl_SetVar2(xcinterp, "XCOps", "pinvisible", (justvalue & PINVISIBLE) ?
+		"true" : "false", TCL_NAMESPACE_ONLY);
 }
 
 /*------------------------------------------------------*/
@@ -2247,7 +2266,6 @@ void setfontmarks(short fvalue, short jvalue)
          XtSetArg(wargs[0], XtNsetMark, False);
       XtSetValues(w, wargs, 1);
 
-#ifdef SCHEMA
       /* Pin visibility property */
       w = NetlistPinVisibilityButton;
       if (jvalue & PINVISIBLE)
@@ -2255,7 +2273,6 @@ void setfontmarks(short fvalue, short jvalue)
       else
          XtSetArg(wargs[0], XtNsetMark, False);
       XtSetValues(w, wargs, 1);
-#endif
    }
 }
 
@@ -2292,7 +2309,7 @@ void stringparam(xcWidget w, caddr_t clientdata, caddr_t calldata)
       if (eventmode == TEXT2_MODE || eventmode == TEXT3_MODE) {
          settext = (genericptr *)EDITPART;
          makeparam(TOLABEL(settext), _STR2);
-         objectdeselect();
+         unselect_all();
 	 setparammarks(NULL);
       }
       else if (checkselect(LABEL)) parameterize(P_SUBSTRING, _STR2);
@@ -2336,7 +2353,7 @@ void startunparam(xcWidget w, pointertype value, caddr_t calldata)
    }
    else
       unparameterize((int)value);
-   objectdeselect();
+   unselect_all();
    setparammarks(NULL);
 }
 
@@ -2462,7 +2479,7 @@ void setvjust(xcWidget w, pointertype value, caddr_t nulldata)
          }
       }
       if (labelcount == 0) setjust(w, value, NULL, 2);
-      else objectdeselect();
+      else unselect_all();
    }
 }
 
@@ -2491,7 +2508,7 @@ void sethjust(xcWidget w, pointertype value, caddr_t nulldata)
          }
       }
       if (labelcount == 0) setjust(w, value, NULL, 1);
-      else objectdeselect();
+      else unselect_all();
    }
 }
 
@@ -2520,7 +2537,7 @@ void setjustbit(xcWidget w, pointertype value, caddr_t nulldata)
          }
       }
       if (labelcount == 0) dojustifybit(w, NULL, (short)value);
-      else objectdeselect();
+      else unselect_all();
    }
 }
 
@@ -2548,7 +2565,7 @@ void setpinjustbit(xcWidget w, pointertype value, caddr_t nulldata)
                dopinjustbit(NULL, settext, (short)value);
          }
       }
-      objectdeselect();
+      unselect_all();
    }
 }
 
@@ -2562,19 +2579,19 @@ void boxedit(xcWidget w, pointertype value, caddr_t nulldata)
 {
    switch (value) {
       case MANHATTAN:
-	 Tcl_SetVar(xcinterp, "polyedittype", "manhattan", TCL_NAMESPACE_ONLY);
+	 Tcl_SetVar2(xcinterp, "XCOps", "polyedittype", "manhattan", TCL_NAMESPACE_ONLY);
 	 break;
       case RHOMBOIDX:
-	 Tcl_SetVar(xcinterp, "polyedittype", "rhomboidx", TCL_NAMESPACE_ONLY);
+	 Tcl_SetVar2(xcinterp, "XCOps", "polyedittype", "rhomboidx", TCL_NAMESPACE_ONLY);
 	 break;
       case RHOMBOIDY:
-	 Tcl_SetVar(xcinterp, "polyedittype", "rhomboidy", TCL_NAMESPACE_ONLY);
+	 Tcl_SetVar2(xcinterp, "XCOps", "polyedittype", "rhomboidy", TCL_NAMESPACE_ONLY);
 	 break;
       case RHOMBOIDA:
-	 Tcl_SetVar(xcinterp, "polyedittype", "rhomboida", TCL_NAMESPACE_ONLY);
+	 Tcl_SetVar2(xcinterp, "XCOps", "polyedittype", "rhomboida", TCL_NAMESPACE_ONLY);
 	 break;
       case NORMAL:
-	 Tcl_SetVar(xcinterp, "polyedittype", "normal", TCL_NAMESPACE_ONLY);
+	 Tcl_SetVar2(xcinterp, "XCOps", "polyedittype", "normal", TCL_NAMESPACE_ONLY);
 	 break;
    }
 
@@ -2814,7 +2831,7 @@ void setfont(xcWidget w, pointertype value, caddr_t calldata)
          }
       }
       if (labelcount == 0) setfontval(w, value, NULL);
-      else objectdeselect();
+      else unselect_all();
    }
 }
 
@@ -2910,7 +2927,7 @@ void fontstyle(xcWidget w, pointertype value, caddr_t nulldata)
          }
       }
       if (labelcount == 0) setfontstyle(w, value, NULL);
-      else objectdeselect();
+      else unselect_all();
    }
 }
 
@@ -3005,7 +3022,7 @@ void fontencoding(xcWidget w, pointertype value, caddr_t nulldata)
          }
       }
       if (labelcount == 0) setfontencoding(w, value, NULL);
-      else objectdeselect();
+      else unselect_all();
    }
 }
 
