@@ -66,6 +66,7 @@ u_char param_select[] = {
    LABEL | OBJINST,				/* P_SCALE */
    POLYGON | SPLINE | ARC | PATH,		/* P_LINEWIDTH */
    ALL_TYPES, 					/* P_COLOR (tbd) */
+   ALL_TYPES,					/* P_EXPRESSION */
    POLYGON | SPLINE | LABEL | OBJINST | ARC 	/* P_POSITION */
 };
 
@@ -428,8 +429,8 @@ int opsubstitute(objectptr thisobj, objinstptr pinst)
 
       for (epp = thiselem->passed; epp != NULL; epp = epp->next) {
 
-	 ips = (pinst != NULL) ?  find_param(pinst, epp->key) : NULL;
 	 ops = match_param(thisobj, epp->key);
+	 ips = (pinst != NULL) ?  find_param(pinst, epp->key) : ops;
 
 	 if (ips != NULL) {
 
@@ -493,7 +494,7 @@ int opsubstitute(objectptr thisobj, objinstptr pinst)
 	       /* Change the key from the parent to the child */
 	       if (strcmp(ops->key, refop->key)) {
 		  free(newop->key);
-		  newop->key = strdup(refop->key);
+		  newop->key = mystrdup(refop->key);
 	       }
 	       continue;
 	    }
@@ -1041,7 +1042,7 @@ eparamptr copyeparam(eparamptr cepp, genericptr thiselem)
 
    newepp = make_new_eparam(cepp->key);
    if (IS_OBJINST(thiselem) && (cepp->pdata.refkey != NULL))
-      newepp->pdata.refkey = strdup(cepp->pdata.refkey);
+      newepp->pdata.refkey = mystrdup(cepp->pdata.refkey);
    else
       newepp->pdata.pointno = cepp->pdata.pointno;
    return newepp;
@@ -1078,7 +1079,7 @@ oparamptr copyparameter(oparamptr cops)
 	 newops->parameter.string = stringcopy(cops->parameter.string);
 	 break;
       case XC_EXPR:
-	 newops->parameter.expr = strdup(cops->parameter.expr);
+	 newops->parameter.expr = mystrdup(cops->parameter.expr);
 	 break;
       case XC_INT: case XC_FLOAT:
 	 newops->parameter.ivalue = cops->parameter.ivalue;
@@ -1137,7 +1138,7 @@ void makeexprparam(objectptr refobject, char *key, char *value, int which)
    refobject->params = newops;
    newops->type = XC_EXPR;		/* expression requiring evaluation */
    newops->which = which;
-   newops->parameter.expr = strdup(value);
+   newops->parameter.expr = mystrdup(value);
    incr_changes(refobject);
 }
 
