@@ -157,6 +157,7 @@ extern void selectsave(xcWidget, caddr_t, caddr_t);
 extern void arceditpush(arcptr);
 extern void splineeditpush(splineptr);
 extern void polyeditpush(polyptr);
+extern void labelcopy(labelptr, labelptr);
 extern void arccopy(arcptr, arcptr);
 extern void polycopy(polyptr, polyptr);
 extern void splinecopy(splineptr, splineptr);
@@ -231,6 +232,11 @@ extern char *varscan(objectptr, char *, short *, genericptr, u_char);
 extern char *varfscan(objectptr, char *, float *, genericptr, u_char);
 extern objinstptr addtoinstlist(int, objectptr, Boolean);
 extern Boolean objectread(FILE *, objectptr, short, short, short, char *, int);
+void importfromlibrary(short, char *, char *);
+objectptr *new_library_object(short, char *, objlistptr *);
+Boolean library_object_unique(short, objectptr, objlistptr);
+void add_object_to_library(short, objectptr);
+
 #ifdef TCL_WRAPPER
 void setfile(char *, int);
 extern xcTimeOutProc savetemp(caddr_t);
