@@ -445,7 +445,7 @@ stringpart *PySetStringParts(PyObject *dval)
 	 }
 	 else if ((ditem = PyDict_GetItemString(litem, "Text")) != NULL) {
 	    newpart->type = TEXT_STRING;
-	    newpart->data.string = strdup(PyString_AsString(ditem));
+	    newpart->data.string = mystrdup(PyString_AsString(ditem));
 	 }
       }
       else if (PyString_Check(litem)) {
@@ -491,7 +491,7 @@ stringpart *PySetStringParts(PyObject *dval)
 	 }
 	 else {
 	    newpart->type = TEXT_STRING;
-	    newpart->data.string = strdup(string);
+	    newpart->data.string = mystrdup(string);
 	 }
       }
    }
