@@ -633,7 +633,7 @@ void collectsubschems(int toppage)
 	  if (xobjs.pagelist[pageno]->filename != NULL)
 	     free(xobjs.pagelist[pageno]->filename);
 	  xobjs.pagelist[pageno]->filename =
-	     strdup(xobjs.pagelist[loctop]->filename);
+	     mystrdup(xobjs.pagelist[loctop]->filename);
       }
    } 
    free((char *)pagelist);
