@@ -252,7 +252,7 @@ Boolean pathselect(genericptr *curgen, short class)
    long		newdist;
    Boolean	selected = False;
 
-   class &= areastruct.filter;	/* apply the selection filter */
+   class &= areastruct.filter;		/* apply the selection filter */
 
    if ((*curgen)->type == (class & ARC)) {
 
@@ -354,7 +354,7 @@ short *genselectelement(short class, u_char mode, objectptr selobj, objinstptr s
       unselect = True;
       class = -class;
    }
-   class &= areastruct.filter;	/* apply the selection filter */
+   class &= areastruct.filter;		/* apply the selection filter */
 
    /* Loop through all elements found underneath the cursor */
 
@@ -702,7 +702,8 @@ void selectarea()
 	   /* do an insideness test with the select box.		*/
 
 	   state = tmpl2 = 0;
-	   for (j = 0; j < stringlength(slab->string, True, areastruct.topinstance); j++) {
+	   for (j = 0; j < stringlength(slab->string, True, areastruct.topinstance);
+			j++) {
 	      strptr = findstringpart(j, &locpos, slab->string, areastruct.topinstance);
 	      if (locpos < 0) continue;	  /* only look at printable characters */
 	      if (strptr->type == RETURN) tmpl2 = 0;
