@@ -58,7 +58,7 @@ short del;
 char *evaluate_expr(oparamptr ops)
 {
    if (ops->type != XC_EXPR) return NULL;
-   return strdup(ops->parameter.expr);
+   return mystrdup(ops->parameter.expr);
 }
 
 #endif
@@ -895,7 +895,7 @@ short UDrawChar(u_char code, short styles, short ffont, int groupheight, int pas
 
    alphapts[0].x = 0;
    alphapts[0].y = 0;
-   charinst.type = OBJECT;
+   charinst.type = OBJINST;
    charinst.color = DEFAULTCOLOR;
    charinst.rotation = 0;
    charinst.scale = fonts[ffont].scale;
@@ -1376,7 +1376,7 @@ void drawtextandupdate(labelptr curlabel, void (*function)(labelptr))
 
    for (pgen = topobject->plist; pgen < topobject->plist + topobject->parts;
 		pgen++) {
-      if ((*pgen)->type == LABEL) {
+      if (IS_LABEL(*pgen)) {
 	 slab = TOLABEL(pgen);
 	 if (slab == curlabel) continue;
 	 if (hasparameter(slab))
@@ -1454,7 +1454,7 @@ void composefontlib(short cfont)
       if ((libobj = fonts[cfont].encoding[i]) == nullobj) continue;
       
       NEW_OBJINST(drawinst, directory);
-      objectdefaults(*drawinst, libobj,
+      instancedefaults(*drawinst, libobj,
 		(i % 16) * del + qdel,		/* X position */
 		-(i / 16) * del + qdel);	/* Y position */
       drawinst = (objinstptr *)directory->plist + directory->parts;
