@@ -32,18 +32,11 @@ typedef unsigned long	u_long;
   #define calloc(a,b) Tcl_Alloc(a * b)
   #define free(a) Tcl_Free((char *)(a))
   #define realloc(a,b) Tcl_Realloc((char *)(a), b)
+  extern char *mystrdup(const char *);
+#else
+  #define mystrdup(c) strdup(c)
 #endif
 
-/*----------------------------------------------------------------------*/
-/* Definition shortcuts 						*/
-/*----------------------------------------------------------------------*/
-
-#define XtnSetArg(a,b)  	XtSetArg(wargs[n], a, b); n++
-#define abs(a)			((a) < 0 ? -(a) : (a))
-#define sign(a)			((a) <= 0 ? -1 : 1)
-#define max(a,b)		((a) < (b) ? (b) : (a))
-#define min(a,b)		((a) < (b) ? (a) : (b))
-
 /*----------------------------------------------------------------------*/
 /* Deal with 32/64 bit processors based on autoconf results.		*/
 /*----------------------------------------------------------------------*/
@@ -58,6 +51,43 @@ typedef u_long pointertype;
 ERROR: Cannot compile without knowing the size of a pointer.  See xcircuit.h.
 #endif
 
+/*----------------------------------------------------------------------*/
+/* Basic element types 							*/
+/*									*/
+/* These values determine how a genericptr should be cast into one of	*/
+/* labelptr, polyptr, etc.  To query the element type, use the macros	*/
+/* ELEMENTTYPE(), IS_LABEL(), IS_POLYGON(), etc.  These macros mask the	*/
+/* bit field.  Note that an element marked with REMOVE_TAG will not be	*/
+/* recognized as any valid element, but otherwise, querying the type is	*/
+/* transparent to other bit settings (such as NETLIST_INVALID).		*/
+/*----------------------------------------------------------------------*/
+
+/* Single-bit flags */
+#define	OBJINST	1
+#define LABEL	2
+#define POLYGON	4
+#define ARC	8
+#define SPLINE  16
+#define PATH	32
+
+#define REMOVE_TAG 64  /* add this value to objects to be removed */
+#define NETLIST_INVALID 128
+#define SELECT_HIDE     256     /* this element cannot be selected      */
+ 
+/* Bit fields */
+#define ALL_TYPES       (OBJINST | LABEL | POLYGON | ARC | SPLINE | PATH)
+#define VALID_TYPES     (REMOVE_TAG | ALL_TYPES)
+
+/*----------------------------------------------------------------------*/
+/* Definition shortcuts 						*/
+/*----------------------------------------------------------------------*/
+
+#define XtnSetArg(a,b)  	XtSetArg(wargs[n], a, b); n++
+#define abs(a)			((a) < 0 ? -(a) : (a))
+#define sign(a)			((a) <= 0 ? -1 : 1)
+#define max(a,b)		((a) < (b) ? (b) : (a))
+#define min(a,b)		((a) < (b) ? (a) : (b))
+
 /*----------------------------------------------------------------------*/
 /* Lengthier define constructs						*/
 /*----------------------------------------------------------------------*/
@@ -419,29 +449,6 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 typedef XPoint* pointlist;
 typedef XfPoint* fpointlist;
 
-/*----------------------------------------------------------------------*/
-/* Basic element types 							*/
-/*									*/
-/* These values determine how a genericptr should be cast into one of	*/
-/* labelptr, polyptr, etc.  To query the element type, use the macros	*/
-/* ELEMENTTYPE(), IS_LABEL(), IS_POLYGON(), etc.  These macros mask the	*/
-/* bit field.  Note that an element marked with REMOVE_TAG will not be	*/
-/* recognized as any valid element, but otherwise, querying the type is	*/
-/* transparent to other bit settings (such as NETLIST_INVALID).		*/
-/*----------------------------------------------------------------------*/
-
-#define	OBJINST	1
-#define LABEL	2
-#define POLYGON	4
-#define ARC	8
-#define SPLINE  16
-#define PATH	32
-#define ALL_TYPES 63
-
-#define REMOVE_TAG 64  /* add this value to objects to be removed */
-#define VALID_TYPES 127
-#define NETLIST_INVALID 128
-
 /*----------------------------------------------------------------------*/
 /* Allowed parameterization types					*/
 /*----------------------------------------------------------------------*/
@@ -531,7 +538,7 @@ typedef struct _eparam {
 /*----------------------------------------------------------------------*/
 
 typedef struct {
-   u_char	type;		/* type is LABEL, POLYGON, etc., from below */
+   u_short	type;		/* type is LABEL, POLYGON, etc., from below */
    int		color;
    eparamptr	passed;
 } generic, *genericptr;		/* (convenience function for retypecasting) */
@@ -552,7 +559,7 @@ typedef struct {
 typedef struct _xcobject *objectptr;
 
 typedef struct {
-   u_char	type;
+   u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
    XPoint	position;
@@ -599,7 +606,7 @@ typedef struct _liblist {
 /*----------------------------------------------------------------------*/
 
 typedef struct {
-   u_char	type;
+   u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
    XPoint	position;
@@ -615,7 +622,7 @@ typedef struct {
 /*----------------------------------------------------------------------*/
 
 typedef struct {
-   u_char	type;
+   u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
    u_short	style;
@@ -629,7 +636,7 @@ typedef struct {
 /*----------------------------------------------------------------------*/
 
 typedef struct {
-   u_char	type;
+   u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
    u_short	style;
@@ -644,7 +651,7 @@ typedef struct {
 /*----------------------------------------------------------------------*/
 
 typedef struct {
-   u_char	type;
+   u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
    u_short	style;
@@ -664,7 +671,7 @@ typedef struct {
 /*----------------------------------------------------------------------*/
 
 typedef struct {
-   u_char	type;
+   u_short	type;
    int		color;
    eparamptr	passed;		/* numerical parameters passed from above */
    u_short	style;
